# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Process.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if 'Process' not in _M_Ice.__dict__:
    _M_Ice.Process = Ice.createTempClass()
    class Process(Ice.Object):
        """
        An administrative interface for process management. Managed servers must
        implement this interface.
        A servant implementing this interface is a potential target
        for denial-of-service attacks, therefore proper security precautions
        should be taken. For example, the servant can use a UUID to make its
        identity harder to guess, and be registered in an object adapter with
        a secured endpoint.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Process:
                raise RuntimeError('Ice.Process is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::Ice::Process')

        def ice_id(self, current=None):
            return '::Ice::Process'

        def ice_staticId():
            return '::Ice::Process'
        ice_staticId = staticmethod(ice_staticId)

        def shutdown(self, current=None):
            """
            Initiate a graceful shut-down.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def writeMessage(self, message, fd, current=None):
            """
            Write a message on the process' stdout or stderr.
            Arguments:
            message -- The message.
            fd -- 1 for stdout, 2 for stderr.
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Process)

        __repr__ = __str__

    _M_Ice.ProcessPrx = Ice.createTempClass()
    class ProcessPrx(Ice.ObjectPrx):

        """
        Initiate a graceful shut-down.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def shutdown(self, _ctx=None):
            return _M_Ice.Process._op_shutdown.invoke(self, ((), _ctx))

        """
        Initiate a graceful shut-down.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_shutdown(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Process._op_shutdown.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Initiate a graceful shut-down.
        Arguments:
        """
        def end_shutdown(self, _r):
            return _M_Ice.Process._op_shutdown.end(self, _r)

        """
        Write a message on the process' stdout or stderr.
        Arguments:
        message -- The message.
        fd -- 1 for stdout, 2 for stderr.
        _ctx -- The request context for the invocation.
        """
        def writeMessage(self, message, fd, _ctx=None):
            return _M_Ice.Process._op_writeMessage.invoke(self, ((message, fd), _ctx))

        """
        Write a message on the process' stdout or stderr.
        Arguments:
        message -- The message.
        fd -- 1 for stdout, 2 for stderr.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_writeMessage(self, message, fd, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Process._op_writeMessage.begin(self, ((message, fd), _response, _ex, _sent, _ctx))

        """
        Write a message on the process' stdout or stderr.
        Arguments:
        message -- The message.
        fd -- 1 for stdout, 2 for stderr.
        """
        def end_writeMessage(self, _r):
            return _M_Ice.Process._op_writeMessage.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.ProcessPrx.ice_checkedCast(proxy, '::Ice::Process', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.ProcessPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::Process'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_ProcessPrx = IcePy.defineProxy('::Ice::Process', ProcessPrx)

    _M_Ice._t_Process = IcePy.defineClass('::Ice::Process', Process, -1, (), True, False, None, (), ())
    Process._ice_type = _M_Ice._t_Process

    Process._op_shutdown = IcePy.Operation('shutdown', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Process._op_writeMessage = IcePy.Operation('writeMessage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_int, False, 0)), (), None, ())

    _M_Ice.Process = Process
    del Process

    _M_Ice.ProcessPrx = ProcessPrx
    del ProcessPrx

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Version.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if 'ProtocolVersion' not in _M_Ice.__dict__:
    _M_Ice.ProtocolVersion = Ice.createTempClass()
    class ProtocolVersion(object):
        """
        A version structure for the protocol version.
        """
        def __init__(self, major=0, minor=0):
            self.major = major
            self.minor = minor

        def __hash__(self):
            _h = 0
            _h = 5 * _h + Ice.getHash(self.major)
            _h = 5 * _h + Ice.getHash(self.minor)
            return _h % 0x7fffffff

        def __compare(self, other):
            if other is None:
                return 1
            elif not isinstance(other, _M_Ice.ProtocolVersion):
                return NotImplemented
            else:
                if self.major is None or other.major is None:
                    if self.major != other.major:
                        return (-1 if self.major is None else 1)
                else:
                    if self.major < other.major:
                        return -1
                    elif self.major > other.major:
                        return 1
                if self.minor is None or other.minor is None:
                    if self.minor != other.minor:
                        return (-1 if self.minor is None else 1)
                else:
                    if self.minor < other.minor:
                        return -1
                    elif self.minor > other.minor:
                        return 1
                return 0

        def __lt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r < 0

        def __le__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r <= 0

        def __gt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r > 0

        def __ge__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r >= 0

        def __eq__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r == 0

        def __ne__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r != 0

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ProtocolVersion)

        __repr__ = __str__

    _M_Ice._t_ProtocolVersion = IcePy.defineStruct('::Ice::ProtocolVersion', ProtocolVersion, (), (
        ('major', (), IcePy._t_byte),
        ('minor', (), IcePy._t_byte)
    ))

    _M_Ice.ProtocolVersion = ProtocolVersion
    del ProtocolVersion

if 'EncodingVersion' not in _M_Ice.__dict__:
    _M_Ice.EncodingVersion = Ice.createTempClass()
    class EncodingVersion(object):
        """
        A version structure for the encoding version.
        """
        def __init__(self, major=0, minor=0):
            self.major = major
            self.minor = minor

        def __hash__(self):
            _h = 0
            _h = 5 * _h + Ice.getHash(self.major)
            _h = 5 * _h + Ice.getHash(self.minor)
            return _h % 0x7fffffff

        def __compare(self, other):
            if other is None:
                return 1
            elif not isinstance(other, _M_Ice.EncodingVersion):
                return NotImplemented
            else:
                if self.major is None or other.major is None:
                    if self.major != other.major:
                        return (-1 if self.major is None else 1)
                else:
                    if self.major < other.major:
                        return -1
                    elif self.major > other.major:
                        return 1
                if self.minor is None or other.minor is None:
                    if self.minor != other.minor:
                        return (-1 if self.minor is None else 1)
                else:
                    if self.minor < other.minor:
                        return -1
                    elif self.minor > other.minor:
                        return 1
                return 0

        def __lt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r < 0

        def __le__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r <= 0

        def __gt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r > 0

        def __ge__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r >= 0

        def __eq__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r == 0

        def __ne__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r != 0

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_EncodingVersion)

        __repr__ = __str__

    _M_Ice._t_EncodingVersion = IcePy.defineStruct('::Ice::EncodingVersion', EncodingVersion, (), (
        ('major', (), IcePy._t_byte),
        ('minor', (), IcePy._t_byte)
    ))

    _M_Ice.EncodingVersion = EncodingVersion
    del EncodingVersion

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `ServantLocator.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_ObjectAdapterF_ice
import Ice_Current_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'ServantLocator' not in _M_Ice.__dict__:
    _M_Ice.ServantLocator = Ice.createTempClass()
    class ServantLocator(object):
        """
        A servant locator is called by an object adapter to
        locate a servant that is not found in its active servant map.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.ServantLocator:
                raise RuntimeError('Ice.ServantLocator is an abstract class')

        def locate(self, curr):
            """
            Called before a request is dispatched if a
            servant cannot be found in the object adapter's active servant
            map. Note that the object adapter does not automatically insert
            the returned servant into its active servant map. This must be
            done by the servant locator implementation, if this is desired.
            locate can throw any user exception. If it does, that exception
            is marshaled back to the client. If the Slice definition for the
            corresponding operation includes that user exception, the client
            receives that user exception; otherwise, the client receives
            UnknownUserException.
            If locate throws any exception, the Ice run time does not
            call finished.
            If you call locate from your own code, you
            must also call finished when you have finished using the
            servant, provided that locate returned a non-null servant;
            otherwise, you will get undefined behavior if you use
            servant locators such as the Freeze Evictor.
            Arguments:
            curr -- Information about the current operation for which a servant is required.
            Returns a tuple containing the following:
            _retval -- The located servant, or null if no suitable servant has been found.
            cookie -- A "cookie" that will be passed to finished.
            Throws:
            UserException -- The implementation can raise a UserException and the run time will marshal it as the result of the invocation.
            """
            pass

        def finished(self, curr, servant, cookie):
            """
            Called by the object adapter after a request has been
            made. This operation is only called if locate was called
            prior to the request and returned a non-null servant. This
            operation can be used for cleanup purposes after a request.
            finished can throw any user exception. If it does, that exception
            is marshaled back to the client. If the Slice definition for the
            corresponding operation includes that user exception, the client
            receives that user exception; otherwise, the client receives
            UnknownUserException.
            If both the operation and finished throw an exception, the
            exception thrown by finished is marshaled back to the client.
            Arguments:
            curr -- Information about the current operation call for which a servant was located by locate.
            servant -- The servant that was returned by locate.
            cookie -- The cookie that was returned by locate.
            Throws:
            UserException -- The implementation can raise a UserException and the run time will marshal it as the result of the invocation.
            """
            pass

        def deactivate(self, category):
            """
            Called when the object adapter in which this servant locator is
            installed is destroyed.
            Arguments:
            category -- Indicates for which category the servant locator is being deactivated.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ServantLocator)

        __repr__ = __str__

    _M_Ice._t_ServantLocator = IcePy.defineClass('::Ice::ServantLocator', ServantLocator, -1, (), True, False, None, (), ())
    ServantLocator._ice_type = _M_Ice._t_ServantLocator

    _M_Ice.ServantLocator = ServantLocator
    del ServantLocator

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Router.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_BuiltinSequences_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'Router' not in _M_Ice.__dict__:
    _M_Ice.Router = Ice.createTempClass()
    class Router(Ice.Object):
        """
        The Ice router interface. Routers can be set either globally with
        Communicator#setDefaultRouter, or with ice_router on specific
        proxies.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Router:
                raise RuntimeError('Ice.Router is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::Ice::Router')

        def ice_id(self, current=None):
            return '::Ice::Router'

        def ice_staticId():
            return '::Ice::Router'
        ice_staticId = staticmethod(ice_staticId)

        def getClientProxy(self, current=None):
            """
            Get the router's client proxy, i.e., the proxy to use for
            forwarding requests from the client to the router.
            If a null proxy is returned, the client will forward requests
            to the router's endpoints.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The router's client proxy.
            """
            pass

        def getServerProxy(self, current=None):
            """
            Get the router's server proxy, i.e., the proxy to use for
            forwarding requests from the server to the router.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The router's server proxy.
            """
            pass

        def addProxies(self, proxies, current=None):
            """
            Add new proxy information to the router's routing table.
            Arguments:
            proxies -- The proxies to add.
            current -- The Current object for the invocation.
            Returns: Proxies discarded by the router.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Router)

        __repr__ = __str__

    _M_Ice.RouterPrx = Ice.createTempClass()
    class RouterPrx(Ice.ObjectPrx):

        """
        Get the router's client proxy, i.e., the proxy to use for
        forwarding requests from the client to the router.
        If a null proxy is returned, the client will forward requests
        to the router's endpoints.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The router's client proxy.
        """
        def getClientProxy(self, _ctx=None):
            return _M_Ice.Router._op_getClientProxy.invoke(self, ((), _ctx))

        """
        Get the router's client proxy, i.e., the proxy to use for
        forwarding requests from the client to the router.
        If a null proxy is returned, the client will forward requests
        to the router's endpoints.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getClientProxy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Router._op_getClientProxy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the router's client proxy, i.e., the proxy to use for
        forwarding requests from the client to the router.
        If a null proxy is returned, the client will forward requests
        to the router's endpoints.
        Arguments:
        Returns: The router's client proxy.
        """
        def end_getClientProxy(self, _r):
            return _M_Ice.Router._op_getClientProxy.end(self, _r)

        """
        Get the router's server proxy, i.e., the proxy to use for
        forwarding requests from the server to the router.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The router's server proxy.
        """
        def getServerProxy(self, _ctx=None):
            return _M_Ice.Router._op_getServerProxy.invoke(self, ((), _ctx))

        """
        Get the router's server proxy, i.e., the proxy to use for
        forwarding requests from the server to the router.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getServerProxy(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Router._op_getServerProxy.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the router's server proxy, i.e., the proxy to use for
        forwarding requests from the server to the router.
        Arguments:
        Returns: The router's server proxy.
        """
        def end_getServerProxy(self, _r):
            return _M_Ice.Router._op_getServerProxy.end(self, _r)

        """
        Add new proxy information to the router's routing table.
        Arguments:
        proxies -- The proxies to add.
        _ctx -- The request context for the invocation.
        Returns: Proxies discarded by the router.
        """
        def addProxies(self, proxies, _ctx=None):
            return _M_Ice.Router._op_addProxies.invoke(self, ((proxies, ), _ctx))

        """
        Add new proxy information to the router's routing table.
        Arguments:
        proxies -- The proxies to add.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_addProxies(self, proxies, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Router._op_addProxies.begin(self, ((proxies, ), _response, _ex, _sent, _ctx))

        """
        Add new proxy information to the router's routing table.
        Arguments:
        proxies -- The proxies to add.
        Returns: Proxies discarded by the router.
        """
        def end_addProxies(self, _r):
            return _M_Ice.Router._op_addProxies.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.RouterPrx.ice_checkedCast(proxy, '::Ice::Router', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.RouterPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::Router'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_RouterPrx = IcePy.defineProxy('::Ice::Router', RouterPrx)

    _M_Ice._t_Router = IcePy.defineClass('::Ice::Router', Router, -1, (), True, False, None, (), ())
    Router._ice_type = _M_Ice._t_Router

    Router._op_getClientProxy = IcePy.Operation('getClientProxy', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Router._op_getServerProxy = IcePy.Operation('getServerProxy', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Router._op_addProxies = IcePy.Operation('addProxies', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_Ice._t_ObjectProxySeq, False, 0),), (), ((), _M_Ice._t_ObjectProxySeq, False, 0), ())

    _M_Ice.Router = Router
    del Router

    _M_Ice.RouterPrx = RouterPrx
    del RouterPrx

if 'RouterFinder' not in _M_Ice.__dict__:
    _M_Ice.RouterFinder = Ice.createTempClass()
    class RouterFinder(Ice.Object):
        """
        This inferface should be implemented by services implementing the
        Ice::Router interface. It should be advertised through an Ice
        object with the identity `Ice/RouterFinder'. This allows clients to
        retrieve the router proxy with just the endpoint information of the
        service.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.RouterFinder:
                raise RuntimeError('Ice.RouterFinder is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::Ice::RouterFinder')

        def ice_id(self, current=None):
            return '::Ice::RouterFinder'

        def ice_staticId():
            return '::Ice::RouterFinder'
        ice_staticId = staticmethod(ice_staticId)

        def getRouter(self, current=None):
            """
            Get the router proxy implemented by the process hosting this
            finder object. The proxy might point to several replicas.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The router proxy.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_RouterFinder)

        __repr__ = __str__

    _M_Ice.RouterFinderPrx = Ice.createTempClass()
    class RouterFinderPrx(Ice.ObjectPrx):

        """
        Get the router proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The router proxy.
        """
        def getRouter(self, _ctx=None):
            return _M_Ice.RouterFinder._op_getRouter.invoke(self, ((), _ctx))

        """
        Get the router proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getRouter(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.RouterFinder._op_getRouter.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the router proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        Returns: The router proxy.
        """
        def end_getRouter(self, _r):
            return _M_Ice.RouterFinder._op_getRouter.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.RouterFinderPrx.ice_checkedCast(proxy, '::Ice::RouterFinder', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.RouterFinderPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::RouterFinder'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_RouterFinderPrx = IcePy.defineProxy('::Ice::RouterFinder', RouterFinderPrx)

    _M_Ice._t_RouterFinder = IcePy.defineClass('::Ice::RouterFinder', RouterFinder, -1, (), True, False, None, (), ())
    RouterFinder._ice_type = _M_Ice._t_RouterFinder

    RouterFinder._op_getRouter = IcePy.Operation('getRouter', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_Ice._t_RouterPrx, False, 0), ())

    _M_Ice.RouterFinder = RouterFinder
    del RouterFinder

    _M_Ice.RouterFinderPrx = RouterFinderPrx
    del RouterFinderPrx

# End of module Ice



print("import: 'Glacier2'")
import Glacier2

print("import: 'Ice'")
import Ice

print("import: 'IceBox'")
import IceBox

print("import: 'IceGrid'")
import IceGrid

print("import: 'IceMX'")
import IceMX

print("import: 'IcePatch2'")
import IcePatch2

print("import: 'IceStorm'")
import IceStorm




# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Logger.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if 'Logger' not in _M_Ice.__dict__:
    _M_Ice.Logger = Ice.createTempClass()
    class Logger(object):
        """
        The Ice message logger. Applications can provide their own logger
        by implementing this interface and installing it in a communicator.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Logger:
                raise RuntimeError('Ice.Logger is an abstract class')

        def _print(self, message):
            """
            Print a message. The message is printed literally, without
            any decorations such as executable name or time stamp.
            Arguments:
            message -- The message to log.
            """
            pass

        def trace(self, category, message):
            """
            Log a trace message.
            Arguments:
            category -- The trace category.
            message -- The trace message to log.
            """
            pass

        def warning(self, message):
            """
            Log a warning message.
            Arguments:
            message -- The warning message to log.
            """
            pass

        def error(self, message):
            """
            Log an error message.
            Arguments:
            message -- The error message to log.
            """
            pass

        def getPrefix(self):
            """
            Returns this logger's prefix.
            Returns: The prefix.
            """
            pass

        def cloneWithPrefix(self, prefix):
            """
            Returns a clone of the logger with a new prefix.
            Arguments:
            prefix -- The new prefix for the logger.
            Returns: A logger instance.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Logger)

        __repr__ = __str__

    _M_Ice._t_Logger = IcePy.defineClass('::Ice::Logger', Logger, -1, (), True, False, None, (), ())
    Logger._ice_type = _M_Ice._t_Logger

    _M_Ice.Logger = Logger
    del Logger

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Locator.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_Identity_ice
import Ice_ProcessF_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'AdapterNotFoundException' not in _M_Ice.__dict__:
    _M_Ice.AdapterNotFoundException = Ice.createTempClass()
    class AdapterNotFoundException(Ice.UserException):
        """
        This exception is raised if an adapter cannot be found.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Ice::AdapterNotFoundException'

    _M_Ice._t_AdapterNotFoundException = IcePy.defineException('::Ice::AdapterNotFoundException', AdapterNotFoundException, (), False, None, ())
    AdapterNotFoundException._ice_type = _M_Ice._t_AdapterNotFoundException

    _M_Ice.AdapterNotFoundException = AdapterNotFoundException
    del AdapterNotFoundException

if 'InvalidReplicaGroupIdException' not in _M_Ice.__dict__:
    _M_Ice.InvalidReplicaGroupIdException = Ice.createTempClass()
    class InvalidReplicaGroupIdException(Ice.UserException):
        """
        This exception is raised if the replica group provided by the
        server is invalid.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Ice::InvalidReplicaGroupIdException'

    _M_Ice._t_InvalidReplicaGroupIdException = IcePy.defineException('::Ice::InvalidReplicaGroupIdException', InvalidReplicaGroupIdException, (), False, None, ())
    InvalidReplicaGroupIdException._ice_type = _M_Ice._t_InvalidReplicaGroupIdException

    _M_Ice.InvalidReplicaGroupIdException = InvalidReplicaGroupIdException
    del InvalidReplicaGroupIdException

if 'AdapterAlreadyActiveException' not in _M_Ice.__dict__:
    _M_Ice.AdapterAlreadyActiveException = Ice.createTempClass()
    class AdapterAlreadyActiveException(Ice.UserException):
        """
        This exception is raised if a server tries to set endpoints for
        an adapter that is already active.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Ice::AdapterAlreadyActiveException'

    _M_Ice._t_AdapterAlreadyActiveException = IcePy.defineException('::Ice::AdapterAlreadyActiveException', AdapterAlreadyActiveException, (), False, None, ())
    AdapterAlreadyActiveException._ice_type = _M_Ice._t_AdapterAlreadyActiveException

    _M_Ice.AdapterAlreadyActiveException = AdapterAlreadyActiveException
    del AdapterAlreadyActiveException

if 'ObjectNotFoundException' not in _M_Ice.__dict__:
    _M_Ice.ObjectNotFoundException = Ice.createTempClass()
    class ObjectNotFoundException(Ice.UserException):
        """
        This exception is raised if an object cannot be found.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Ice::ObjectNotFoundException'

    _M_Ice._t_ObjectNotFoundException = IcePy.defineException('::Ice::ObjectNotFoundException', ObjectNotFoundException, (), False, None, ())
    ObjectNotFoundException._ice_type = _M_Ice._t_ObjectNotFoundException

    _M_Ice.ObjectNotFoundException = ObjectNotFoundException
    del ObjectNotFoundException

if 'ServerNotFoundException' not in _M_Ice.__dict__:
    _M_Ice.ServerNotFoundException = Ice.createTempClass()
    class ServerNotFoundException(Ice.UserException):
        """
        This exception is raised if a server cannot be found.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'Ice::ServerNotFoundException'

    _M_Ice._t_ServerNotFoundException = IcePy.defineException('::Ice::ServerNotFoundException', ServerNotFoundException, (), False, None, ())
    ServerNotFoundException._ice_type = _M_Ice._t_ServerNotFoundException

    _M_Ice.ServerNotFoundException = ServerNotFoundException
    del ServerNotFoundException

if 'LocatorRegistry' not in _M_Ice.__dict__:
    _M_Ice._t_LocatorRegistry = IcePy.declareClass('::Ice::LocatorRegistry')
    _M_Ice._t_LocatorRegistryPrx = IcePy.declareProxy('::Ice::LocatorRegistry')

if 'Locator' not in _M_Ice.__dict__:
    _M_Ice.Locator = Ice.createTempClass()
    class Locator(Ice.Object):
        """
        The Ice locator interface. This interface is used by clients to
        lookup adapters and objects. It is also used by servers to get the
        locator registry proxy.
        The Locator interface is intended to be used by
        Ice internals and by locator implementations. Regular user code
        should not attempt to use any functionality of this interface
        directly.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Locator:
                raise RuntimeError('Ice.Locator is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Locator', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Ice::Locator'

        def ice_staticId():
            return '::Ice::Locator'
        ice_staticId = staticmethod(ice_staticId)

        def findObjectById_async(self, _cb, id, current=None):
            """
            Find an object by identity and return a proxy that contains
            the adapter ID or endpoints which can be used to access the
            object.
            Arguments:
            _cb -- The asynchronous callback object.
            id -- The identity.
            current -- The Current object for the invocation.
            Throws:
            Ice.ObjectNotFoundException -- Raised if the object cannot be found.
            """
            pass

        def findAdapterById_async(self, _cb, id, current=None):
            """
            Find an adapter by id and return a proxy that contains
            its endpoints.
            Arguments:
            _cb -- The asynchronous callback object.
            id -- The adapter id.
            current -- The Current object for the invocation.
            Throws:
            Ice.AdapterNotFoundException -- Raised if the adapter cannot be found.
            """
            pass

        def getRegistry(self, current=None):
            """
            Get the locator registry.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The locator registry.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Locator)

        __repr__ = __str__

    _M_Ice.LocatorPrx = Ice.createTempClass()
    class LocatorPrx(Ice.ObjectPrx):

        """
        Find an object by identity and return a proxy that contains
        the adapter ID or endpoints which can be used to access the
        object.
        Arguments:
        id -- The identity.
        _ctx -- The request context for the invocation.
        Returns: The proxy, or null if the object is not active.
        Throws:
        Ice.ObjectNotFoundException -- Raised if the object cannot be found.
        """
        def findObjectById(self, id, _ctx=None):
            return _M_Ice.Locator._op_findObjectById.invoke(self, ((id, ), _ctx))

        """
        Find an object by identity and return a proxy that contains
        the adapter ID or endpoints which can be used to access the
        object.
        Arguments:
        id -- The identity.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectById(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Locator._op_findObjectById.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        Find an object by identity and return a proxy that contains
        the adapter ID or endpoints which can be used to access the
        object.
        Arguments:
        id -- The identity.
        Returns: The proxy, or null if the object is not active.
        Throws:
        Ice.ObjectNotFoundException -- Raised if the object cannot be found.
        """
        def end_findObjectById(self, _r):
            return _M_Ice.Locator._op_findObjectById.end(self, _r)

        """
        Find an adapter by id and return a proxy that contains
        its endpoints.
        Arguments:
        id -- The adapter id.
        _ctx -- The request context for the invocation.
        Returns: The adapter proxy, or null if the adapter is not active.
        Throws:
        Ice.AdapterNotFoundException -- Raised if the adapter cannot be found.
        """
        def findAdapterById(self, id, _ctx=None):
            return _M_Ice.Locator._op_findAdapterById.invoke(self, ((id, ), _ctx))

        """
        Find an adapter by id and return a proxy that contains
        its endpoints.
        Arguments:
        id -- The adapter id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findAdapterById(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Locator._op_findAdapterById.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        Find an adapter by id and return a proxy that contains
        its endpoints.
        Arguments:
        id -- The adapter id.
        Returns: The adapter proxy, or null if the adapter is not active.
        Throws:
        Ice.AdapterNotFoundException -- Raised if the adapter cannot be found.
        """
        def end_findAdapterById(self, _r):
            return _M_Ice.Locator._op_findAdapterById.end(self, _r)

        """
        Get the locator registry.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The locator registry.
        """
        def getRegistry(self, _ctx=None):
            return _M_Ice.Locator._op_getRegistry.invoke(self, ((), _ctx))

        """
        Get the locator registry.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getRegistry(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.Locator._op_getRegistry.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the locator registry.
        Arguments:
        Returns: The locator registry.
        """
        def end_getRegistry(self, _r):
            return _M_Ice.Locator._op_getRegistry.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.LocatorPrx.ice_checkedCast(proxy, '::Ice::Locator', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.LocatorPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::Locator'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_LocatorPrx = IcePy.defineProxy('::Ice::Locator', LocatorPrx)

    _M_Ice._t_Locator = IcePy.defineClass('::Ice::Locator', Locator, -1, (), True, False, None, (), ())
    Locator._ice_type = _M_Ice._t_Locator

    Locator._op_findObjectById = IcePy.Operation('findObjectById', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, True, None, (), (((), _M_Ice._t_Identity, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), (_M_Ice._t_ObjectNotFoundException,))
    Locator._op_findAdapterById = IcePy.Operation('findAdapterById', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, True, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), (_M_Ice._t_AdapterNotFoundException,))
    Locator._op_getRegistry = IcePy.Operation('getRegistry', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), _M_Ice._t_LocatorRegistryPrx, False, 0), ())

    _M_Ice.Locator = Locator
    del Locator

    _M_Ice.LocatorPrx = LocatorPrx
    del LocatorPrx

if 'LocatorRegistry' not in _M_Ice.__dict__:
    _M_Ice.LocatorRegistry = Ice.createTempClass()
    class LocatorRegistry(Ice.Object):
        """
        The Ice locator registry interface. This interface is used by
        servers to register adapter endpoints with the locator.
         The LocatorRegistry interface is intended to be used
        by Ice internals and by locator implementations. Regular user
        code should not attempt to use any functionality of this interface
        directly.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.LocatorRegistry:
                raise RuntimeError('Ice.LocatorRegistry is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::LocatorRegistry', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Ice::LocatorRegistry'

        def ice_staticId():
            return '::Ice::LocatorRegistry'
        ice_staticId = staticmethod(ice_staticId)

        def setAdapterDirectProxy_async(self, _cb, id, proxy, current=None):
            """
            Set the adapter endpoints with the locator registry.
            Arguments:
            _cb -- The asynchronous callback object.
            id -- The adapter id.
            proxy -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
            current -- The Current object for the invocation.
            Throws:
            AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
            AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
            """
            pass

        def setReplicatedAdapterDirectProxy_async(self, _cb, adapterId, replicaGroupId, p, current=None):
            """
            Set the adapter endpoints with the locator registry.
            Arguments:
            _cb -- The asynchronous callback object.
            adapterId -- The adapter id.
            replicaGroupId -- The replica group id.
            p -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
            current -- The Current object for the invocation.
            Throws:
            AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
            AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
            InvalidReplicaGroupIdException -- Raised if the given replica group doesn't match the one registered with the locator registry for this object adapter.
            """
            pass

        def setServerProcessProxy_async(self, _cb, id, proxy, current=None):
            """
            Set the process proxy for a server.
            Arguments:
            _cb -- The asynchronous callback object.
            id -- The server id.
            proxy -- The process proxy.
            current -- The Current object for the invocation.
            Throws:
            ServerNotFoundException -- Raised if the server cannot be found.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_LocatorRegistry)

        __repr__ = __str__

    _M_Ice.LocatorRegistryPrx = Ice.createTempClass()
    class LocatorRegistryPrx(Ice.ObjectPrx):

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        id -- The adapter id.
        proxy -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        _ctx -- The request context for the invocation.
        Throws:
        AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
        AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
        """
        def setAdapterDirectProxy(self, id, proxy, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setAdapterDirectProxy.invoke(self, ((id, proxy), _ctx))

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        id -- The adapter id.
        proxy -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setAdapterDirectProxy(self, id, proxy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setAdapterDirectProxy.begin(self, ((id, proxy), _response, _ex, _sent, _ctx))

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        id -- The adapter id.
        proxy -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        Throws:
        AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
        AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
        """
        def end_setAdapterDirectProxy(self, _r):
            return _M_Ice.LocatorRegistry._op_setAdapterDirectProxy.end(self, _r)

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        adapterId -- The adapter id.
        replicaGroupId -- The replica group id.
        p -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        _ctx -- The request context for the invocation.
        Throws:
        AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
        AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
        InvalidReplicaGroupIdException -- Raised if the given replica group doesn't match the one registered with the locator registry for this object adapter.
        """
        def setReplicatedAdapterDirectProxy(self, adapterId, replicaGroupId, p, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setReplicatedAdapterDirectProxy.invoke(self, ((adapterId, replicaGroupId, p), _ctx))

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        adapterId -- The adapter id.
        replicaGroupId -- The replica group id.
        p -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setReplicatedAdapterDirectProxy(self, adapterId, replicaGroupId, p, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setReplicatedAdapterDirectProxy.begin(self, ((adapterId, replicaGroupId, p), _response, _ex, _sent, _ctx))

        """
        Set the adapter endpoints with the locator registry.
        Arguments:
        adapterId -- The adapter id.
        replicaGroupId -- The replica group id.
        p -- The adapter proxy (a dummy direct proxy created by the adapter). The direct proxy contains the adapter endpoints.
        Throws:
        AdapterAlreadyActiveException -- Raised if an adapter with the same id is already active.
        AdapterNotFoundException -- Raised if the adapter cannot be found, or if the locator only allows registered adapters to set their active proxy and the adapter is not registered with the locator.
        InvalidReplicaGroupIdException -- Raised if the given replica group doesn't match the one registered with the locator registry for this object adapter.
        """
        def end_setReplicatedAdapterDirectProxy(self, _r):
            return _M_Ice.LocatorRegistry._op_setReplicatedAdapterDirectProxy.end(self, _r)

        """
        Set the process proxy for a server.
        Arguments:
        id -- The server id.
        proxy -- The process proxy.
        _ctx -- The request context for the invocation.
        Throws:
        ServerNotFoundException -- Raised if the server cannot be found.
        """
        def setServerProcessProxy(self, id, proxy, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setServerProcessProxy.invoke(self, ((id, proxy), _ctx))

        """
        Set the process proxy for a server.
        Arguments:
        id -- The server id.
        proxy -- The process proxy.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_setServerProcessProxy(self, id, proxy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.LocatorRegistry._op_setServerProcessProxy.begin(self, ((id, proxy), _response, _ex, _sent, _ctx))

        """
        Set the process proxy for a server.
        Arguments:
        id -- The server id.
        proxy -- The process proxy.
        Throws:
        ServerNotFoundException -- Raised if the server cannot be found.
        """
        def end_setServerProcessProxy(self, _r):
            return _M_Ice.LocatorRegistry._op_setServerProcessProxy.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.LocatorRegistryPrx.ice_checkedCast(proxy, '::Ice::LocatorRegistry', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.LocatorRegistryPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::LocatorRegistry'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_LocatorRegistryPrx = IcePy.defineProxy('::Ice::LocatorRegistry', LocatorRegistryPrx)

    _M_Ice._t_LocatorRegistry = IcePy.defineClass('::Ice::LocatorRegistry', LocatorRegistry, -1, (), True, False, None, (), ())
    LocatorRegistry._ice_type = _M_Ice._t_LocatorRegistry

    LocatorRegistry._op_setAdapterDirectProxy = IcePy.Operation('setAdapterDirectProxy', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_ObjectPrx, False, 0)), (), None, (_M_Ice._t_AdapterNotFoundException, _M_Ice._t_AdapterAlreadyActiveException))
    LocatorRegistry._op_setReplicatedAdapterDirectProxy = IcePy.Operation('setReplicatedAdapterDirectProxy', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0), ((), IcePy._t_ObjectPrx, False, 0)), (), None, (_M_Ice._t_AdapterNotFoundException, _M_Ice._t_AdapterAlreadyActiveException, _M_Ice._t_InvalidReplicaGroupIdException))
    LocatorRegistry._op_setServerProcessProxy = IcePy.Operation('setServerProcessProxy', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, True, None, (), (((), IcePy._t_string, False, 0), ((), _M_Ice._t_ProcessPrx, False, 0)), (), None, (_M_Ice._t_ServerNotFoundException,))

    _M_Ice.LocatorRegistry = LocatorRegistry
    del LocatorRegistry

    _M_Ice.LocatorRegistryPrx = LocatorRegistryPrx
    del LocatorRegistryPrx

if 'LocatorFinder' not in _M_Ice.__dict__:
    _M_Ice.LocatorFinder = Ice.createTempClass()
    class LocatorFinder(Ice.Object):
        """
        This inferface should be implemented by services implementing the
        Ice::Locator interface. It should be advertised through an Ice
        object with the identity `Ice/LocatorFinder'. This allows clients
        to retrieve the locator proxy with just the endpoint information of
        the service.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.LocatorFinder:
                raise RuntimeError('Ice.LocatorFinder is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::LocatorFinder', '::Ice::Object')

        def ice_id(self, current=None):
            return '::Ice::LocatorFinder'

        def ice_staticId():
            return '::Ice::LocatorFinder'
        ice_staticId = staticmethod(ice_staticId)

        def getLocator(self, current=None):
            """
            Get the locator proxy implemented by the process hosting this
            finder object. The proxy might point to several replicas.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The locator proxy.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_LocatorFinder)

        __repr__ = __str__

    _M_Ice.LocatorFinderPrx = Ice.createTempClass()
    class LocatorFinderPrx(Ice.ObjectPrx):

        """
        Get the locator proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The locator proxy.
        """
        def getLocator(self, _ctx=None):
            return _M_Ice.LocatorFinder._op_getLocator.invoke(self, ((), _ctx))

        """
        Get the locator proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getLocator(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_Ice.LocatorFinder._op_getLocator.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the locator proxy implemented by the process hosting this
        finder object. The proxy might point to several replicas.
        Arguments:
        Returns: The locator proxy.
        """
        def end_getLocator(self, _r):
            return _M_Ice.LocatorFinder._op_getLocator.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_Ice.LocatorFinderPrx.ice_checkedCast(proxy, '::Ice::LocatorFinder', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_Ice.LocatorFinderPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::Ice::LocatorFinder'
        ice_staticId = staticmethod(ice_staticId)

    _M_Ice._t_LocatorFinderPrx = IcePy.defineProxy('::Ice::LocatorFinder', LocatorFinderPrx)

    _M_Ice._t_LocatorFinder = IcePy.defineClass('::Ice::LocatorFinder', LocatorFinder, -1, (), True, False, None, (), ())
    LocatorFinder._ice_type = _M_Ice._t_LocatorFinder

    LocatorFinder._op_getLocator = IcePy.Operation('getLocator', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_Ice._t_LocatorPrx, False, 0), ())

    _M_Ice.LocatorFinder = LocatorFinder
    del LocatorFinder

    _M_Ice.LocatorFinderPrx = LocatorFinderPrx
    del LocatorFinderPrx

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Query.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_Identity_ice
import Ice_BuiltinSequences_ice
import IceGrid_Exception_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Start of module IceGrid
__name__ = 'IceGrid'
_M_IceGrid.__doc__ = """
IceGrid is a server activation and deployment tool. IceGrid,
simplifies the complex task of deploying applications in a
heterogeneous computer network.
"""

if 'LoadSample' not in _M_IceGrid.__dict__:
    _M_IceGrid.LoadSample = Ice.createTempClass()
    class LoadSample(Ice.EnumBase):
        """
        Determines which load sampling interval to use.
        Enumerators:
        LoadSample1 -- Sample every minute.
        LoadSample5 -- Sample every five minutes.
        LoadSample15 -- Sample every fifteen minutes.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    LoadSample.LoadSample1 = LoadSample("LoadSample1", 0)
    LoadSample.LoadSample5 = LoadSample("LoadSample5", 1)
    LoadSample.LoadSample15 = LoadSample("LoadSample15", 2)
    LoadSample._enumerators = { 0:LoadSample.LoadSample1, 1:LoadSample.LoadSample5, 2:LoadSample.LoadSample15 }

    _M_IceGrid._t_LoadSample = IcePy.defineEnum('::IceGrid::LoadSample', LoadSample, (), LoadSample._enumerators)

    _M_IceGrid.LoadSample = LoadSample
    del LoadSample

if 'Query' not in _M_IceGrid.__dict__:
    _M_IceGrid.Query = Ice.createTempClass()
    class Query(Ice.Object):
        """
        The IceGrid query interface. This interface is accessible to
        Ice clients who wish to look up well-known objects.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.Query:
                raise RuntimeError('IceGrid.Query is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::Query')

        def ice_id(self, current=None):
            return '::IceGrid::Query'

        def ice_staticId():
            return '::IceGrid::Query'
        ice_staticId = staticmethod(ice_staticId)

        def findObjectById(self, id, current=None):
            """
            Find a well-known object by identity.
            Arguments:
            id -- The identity.
            current -- The Current object for the invocation.
            Returns: The proxy or null if no such object has been found.
            """
            pass

        def findObjectByType(self, type, current=None):
            """
            Find a well-known object by type. If there are several objects
            registered for the given type, the object is randomly
            selected.
            Arguments:
            type -- The object type.
            current -- The Current object for the invocation.
            Returns: The proxy or null, if no such object has been found.
            """
            pass

        def findObjectByTypeOnLeastLoadedNode(self, type, sample, current=None):
            """
            Find a well-known object by type on the least-loaded node. If
            the registry does not know which node hosts the object
            (for example, because the object was registered with a direct proxy), the
            registry assumes the object is hosted on a node that has a load
            average of 1.0.
            Arguments:
            type -- The object type.
            sample -- The sampling interval.
            current -- The Current object for the invocation.
            Returns: The proxy or null, if no such object has been found.
            """
            pass

        def findAllObjectsByType(self, type, current=None):
            """
            Find all the well-known objects with the given type.
            Arguments:
            type -- The object type.
            current -- The Current object for the invocation.
            Returns: The proxies or an empty sequence, if no such objects have been found.
            """
            pass

        def findAllReplicas(self, proxy, current=None):
            """
            Find all the object replicas associated with the given
            proxy. If the given proxy is not an indirect proxy from a
            replica group, an empty sequence is returned.
            Arguments:
            proxy -- The object proxy.
            current -- The Current object for the invocation.
            Returns: The proxies of each object replica or an empty sequence, if the given proxy is not from a replica group.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_Query)

        __repr__ = __str__

    _M_IceGrid.QueryPrx = Ice.createTempClass()
    class QueryPrx(Ice.ObjectPrx):

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        _ctx -- The request context for the invocation.
        Returns: The proxy or null if no such object has been found.
        """
        def findObjectById(self, id, _ctx=None):
            return _M_IceGrid.Query._op_findObjectById.invoke(self, ((id, ), _ctx))

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectById(self, id, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Query._op_findObjectById.begin(self, ((id, ), _response, _ex, _sent, _ctx))

        """
        Find a well-known object by identity.
        Arguments:
        id -- The identity.
        Returns: The proxy or null if no such object has been found.
        """
        def end_findObjectById(self, _r):
            return _M_IceGrid.Query._op_findObjectById.end(self, _r)

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        _ctx -- The request context for the invocation.
        Returns: The proxy or null, if no such object has been found.
        """
        def findObjectByType(self, type, _ctx=None):
            return _M_IceGrid.Query._op_findObjectByType.invoke(self, ((type, ), _ctx))

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectByType(self, type, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Query._op_findObjectByType.begin(self, ((type, ), _response, _ex, _sent, _ctx))

        """
        Find a well-known object by type. If there are several objects
        registered for the given type, the object is randomly
        selected.
        Arguments:
        type -- The object type.
        Returns: The proxy or null, if no such object has been found.
        """
        def end_findObjectByType(self, _r):
            return _M_IceGrid.Query._op_findObjectByType.end(self, _r)

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        _ctx -- The request context for the invocation.
        Returns: The proxy or null, if no such object has been found.
        """
        def findObjectByTypeOnLeastLoadedNode(self, type, sample, _ctx=None):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.invoke(self, ((type, sample), _ctx))

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findObjectByTypeOnLeastLoadedNode(self, type, sample, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.begin(self, ((type, sample), _response, _ex, _sent, _ctx))

        """
        Find a well-known object by type on the least-loaded node. If
        the registry does not know which node hosts the object
        (for example, because the object was registered with a direct proxy), the
        registry assumes the object is hosted on a node that has a load
        average of 1.0.
        Arguments:
        type -- The object type.
        sample -- The sampling interval.
        Returns: The proxy or null, if no such object has been found.
        """
        def end_findObjectByTypeOnLeastLoadedNode(self, _r):
            return _M_IceGrid.Query._op_findObjectByTypeOnLeastLoadedNode.end(self, _r)

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        _ctx -- The request context for the invocation.
        Returns: The proxies or an empty sequence, if no such objects have been found.
        """
        def findAllObjectsByType(self, type, _ctx=None):
            return _M_IceGrid.Query._op_findAllObjectsByType.invoke(self, ((type, ), _ctx))

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findAllObjectsByType(self, type, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Query._op_findAllObjectsByType.begin(self, ((type, ), _response, _ex, _sent, _ctx))

        """
        Find all the well-known objects with the given type.
        Arguments:
        type -- The object type.
        Returns: The proxies or an empty sequence, if no such objects have been found.
        """
        def end_findAllObjectsByType(self, _r):
            return _M_IceGrid.Query._op_findAllObjectsByType.end(self, _r)

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        _ctx -- The request context for the invocation.
        Returns: The proxies of each object replica or an empty sequence, if the given proxy is not from a replica group.
        """
        def findAllReplicas(self, proxy, _ctx=None):
            return _M_IceGrid.Query._op_findAllReplicas.invoke(self, ((proxy, ), _ctx))

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_findAllReplicas(self, proxy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Query._op_findAllReplicas.begin(self, ((proxy, ), _response, _ex, _sent, _ctx))

        """
        Find all the object replicas associated with the given
        proxy. If the given proxy is not an indirect proxy from a
        replica group, an empty sequence is returned.
        Arguments:
        proxy -- The object proxy.
        Returns: The proxies of each object replica or an empty sequence, if the given proxy is not from a replica group.
        """
        def end_findAllReplicas(self, _r):
            return _M_IceGrid.Query._op_findAllReplicas.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.QueryPrx.ice_checkedCast(proxy, '::IceGrid::Query', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.QueryPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::Query'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_QueryPrx = IcePy.defineProxy('::IceGrid::Query', QueryPrx)

    _M_IceGrid._t_Query = IcePy.defineClass('::IceGrid::Query', Query, -1, (), True, False, None, (), ())
    Query._ice_type = _M_IceGrid._t_Query

    Query._op_findObjectById = IcePy.Operation('findObjectById', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), _M_Ice._t_Identity, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findObjectByType = IcePy.Operation('findObjectByType', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findObjectByTypeOnLeastLoadedNode = IcePy.Operation('findObjectByTypeOnLeastLoadedNode', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_IceGrid._t_LoadSample, False, 0)), (), ((), IcePy._t_ObjectPrx, False, 0), ())
    Query._op_findAllObjectsByType = IcePy.Operation('findAllObjectsByType', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_Ice._t_ObjectProxySeq, False, 0), ())
    Query._op_findAllReplicas = IcePy.Operation('findAllReplicas', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_ObjectPrx, False, 0),), (), ((), _M_Ice._t_ObjectProxySeq, False, 0), ())

    _M_IceGrid.Query = Query
    del Query

    _M_IceGrid.QueryPrx = QueryPrx
    del QueryPrx

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::LoadSample"] = "ec48c06fa099138a5fbbce121a9a290"
Ice.sliceChecksums["::IceGrid::Query"] = "39dbe5f62c19aa42c2e0fbaf220b4f1"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Connection.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_ObjectAdapterF_ice
import Ice_Identity_ice
import Ice_Endpoint_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'ConnectionInfo' not in _M_Ice.__dict__:
    _M_Ice.ConnectionInfo = Ice.createTempClass()
    class ConnectionInfo(object):
        """
        Base class providing access to the connection details. *
        Members:
        incoming -- Whether or not the connection is an incoming or outgoing
        connection.
        adapterName -- The name of the adapter associated with the connection.
        connectionId -- The connection id.
        rcvSize -- The connection buffer receive size.
        sndSize -- The connection buffer send size.
        """
        def __init__(self, incoming=False, adapterName='', connectionId='', rcvSize=0, sndSize=0):
            self.incoming = incoming
            self.adapterName = adapterName
            self.connectionId = connectionId
            self.rcvSize = rcvSize
            self.sndSize = sndSize

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ConnectionInfo)

        __repr__ = __str__

    _M_Ice._t_ConnectionInfo = IcePy.defineClass('::Ice::ConnectionInfo', ConnectionInfo, -1, (), False, False, None, (), (
        ('incoming', (), IcePy._t_bool, False, 0),
        ('adapterName', (), IcePy._t_string, False, 0),
        ('connectionId', (), IcePy._t_string, False, 0),
        ('rcvSize', (), IcePy._t_int, False, 0),
        ('sndSize', (), IcePy._t_int, False, 0)
    ))
    ConnectionInfo._ice_type = _M_Ice._t_ConnectionInfo

    _M_Ice.ConnectionInfo = ConnectionInfo
    del ConnectionInfo

if 'Connection' not in _M_Ice.__dict__:
    _M_Ice._t_Connection = IcePy.declareClass('::Ice::Connection')

if 'ConnectionCallback' not in _M_Ice.__dict__:
    _M_Ice.ConnectionCallback = Ice.createTempClass()
    class ConnectionCallback(object):
        """
        An application can implement this interface to receive notifications when
        a connection closes or receives a heartbeat message.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.ConnectionCallback:
                raise RuntimeError('Ice.ConnectionCallback is an abstract class')

        def heartbeat(self, con):
            """
            This method is called by the the connection when a heartbeat is
            received from the peer.
            Arguments:
            con -- The connection on which a heartbeat was received.
            """
            pass

        def closed(self, con):
            """
            This method is called by the the connection when the connection
            is closed.
            Arguments:
            con -- The connection that closed.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ConnectionCallback)

        __repr__ = __str__

    _M_Ice._t_ConnectionCallback = IcePy.defineClass('::Ice::ConnectionCallback', ConnectionCallback, -1, (), True, False, None, (), ())
    ConnectionCallback._ice_type = _M_Ice._t_ConnectionCallback

    _M_Ice.ConnectionCallback = ConnectionCallback
    del ConnectionCallback

if 'ACMClose' not in _M_Ice.__dict__:
    _M_Ice.ACMClose = Ice.createTempClass()
    class ACMClose(Ice.EnumBase):
        """
        Specifies the close semantics for Active Connection Management.
        Enumerators:
        CloseOff -- Disables automatic connection closure.
        CloseOnIdle -- Gracefully closes a connection that has been idle for the configured timeout period.
        CloseOnInvocation -- Forcefully closes a connection that has been idle for the configured timeout period,
        but only if the connection has pending invocations.
        CloseOnInvocationAndIdle -- Combines the behaviors of CloseOnIdle and CloseOnInvocation.
        CloseOnIdleForceful -- Forcefully closes a connection that has been idle for the configured timeout period,
        regardless of whether the connection has pending invocations or dispatch.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    ACMClose.CloseOff = ACMClose("CloseOff", 0)
    ACMClose.CloseOnIdle = ACMClose("CloseOnIdle", 1)
    ACMClose.CloseOnInvocation = ACMClose("CloseOnInvocation", 2)
    ACMClose.CloseOnInvocationAndIdle = ACMClose("CloseOnInvocationAndIdle", 3)
    ACMClose.CloseOnIdleForceful = ACMClose("CloseOnIdleForceful", 4)
    ACMClose._enumerators = { 0:ACMClose.CloseOff, 1:ACMClose.CloseOnIdle, 2:ACMClose.CloseOnInvocation, 3:ACMClose.CloseOnInvocationAndIdle, 4:ACMClose.CloseOnIdleForceful }

    _M_Ice._t_ACMClose = IcePy.defineEnum('::Ice::ACMClose', ACMClose, (), ACMClose._enumerators)

    _M_Ice.ACMClose = ACMClose
    del ACMClose

if 'ACMHeartbeat' not in _M_Ice.__dict__:
    _M_Ice.ACMHeartbeat = Ice.createTempClass()
    class ACMHeartbeat(Ice.EnumBase):
        """
        Specifies the heartbeat semantics for Active Connection Management.
        Enumerators:
        HeartbeatOff -- Disables heartbeats.
        HeartbeatOnInvocation -- Send a heartbeat at regular intervals if the connection is idle and only if there are pending dispatch.
        HeartbeatOnIdle -- Send a heartbeat at regular intervals when the connection is idle.
        HeartbeatAlways -- Send a heartbeat at regular intervals until the connection is closed.
        """

        def __init__(self, _n, _v):
            Ice.EnumBase.__init__(self, _n, _v)

        def valueOf(self, _n):
            if _n in self._enumerators:
                return self._enumerators[_n]
            return None
        valueOf = classmethod(valueOf)

    ACMHeartbeat.HeartbeatOff = ACMHeartbeat("HeartbeatOff", 0)
    ACMHeartbeat.HeartbeatOnInvocation = ACMHeartbeat("HeartbeatOnInvocation", 1)
    ACMHeartbeat.HeartbeatOnIdle = ACMHeartbeat("HeartbeatOnIdle", 2)
    ACMHeartbeat.HeartbeatAlways = ACMHeartbeat("HeartbeatAlways", 3)
    ACMHeartbeat._enumerators = { 0:ACMHeartbeat.HeartbeatOff, 1:ACMHeartbeat.HeartbeatOnInvocation, 2:ACMHeartbeat.HeartbeatOnIdle, 3:ACMHeartbeat.HeartbeatAlways }

    _M_Ice._t_ACMHeartbeat = IcePy.defineEnum('::Ice::ACMHeartbeat', ACMHeartbeat, (), ACMHeartbeat._enumerators)

    _M_Ice.ACMHeartbeat = ACMHeartbeat
    del ACMHeartbeat

if 'ACM' not in _M_Ice.__dict__:
    _M_Ice.ACM = Ice.createTempClass()
    class ACM(object):
        """
        A collection of Active Connection Management configuration settings.
        Members:
        timeout -- A timeout value in seconds.
        close -- The close semantics.
        heartbeat -- The heartbeat semantics.
        """
        def __init__(self, timeout=0, close=_M_Ice.ACMClose.CloseOff, heartbeat=_M_Ice.ACMHeartbeat.HeartbeatOff):
            self.timeout = timeout
            self.close = close
            self.heartbeat = heartbeat

        def __hash__(self):
            _h = 0
            _h = 5 * _h + Ice.getHash(self.timeout)
            _h = 5 * _h + Ice.getHash(self.close)
            _h = 5 * _h + Ice.getHash(self.heartbeat)
            return _h % 0x7fffffff

        def __compare(self, other):
            if other is None:
                return 1
            elif not isinstance(other, _M_Ice.ACM):
                return NotImplemented
            else:
                if self.timeout is None or other.timeout is None:
                    if self.timeout != other.timeout:
                        return (-1 if self.timeout is None else 1)
                else:
                    if self.timeout < other.timeout:
                        return -1
                    elif self.timeout > other.timeout:
                        return 1
                if self.close is None or other.close is None:
                    if self.close != other.close:
                        return (-1 if self.close is None else 1)
                else:
                    if self.close < other.close:
                        return -1
                    elif self.close > other.close:
                        return 1
                if self.heartbeat is None or other.heartbeat is None:
                    if self.heartbeat != other.heartbeat:
                        return (-1 if self.heartbeat is None else 1)
                else:
                    if self.heartbeat < other.heartbeat:
                        return -1
                    elif self.heartbeat > other.heartbeat:
                        return 1
                return 0

        def __lt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r < 0

        def __le__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r <= 0

        def __gt__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r > 0

        def __ge__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r >= 0

        def __eq__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r == 0

        def __ne__(self, other):
            r = self.__compare(other)
            if r is NotImplemented:
                return r
            else:
                return r != 0

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ACM)

        __repr__ = __str__

    _M_Ice._t_ACM = IcePy.defineStruct('::Ice::ACM', ACM, (), (
        ('timeout', (), IcePy._t_int),
        ('close', (), _M_Ice._t_ACMClose),
        ('heartbeat', (), _M_Ice._t_ACMHeartbeat)
    ))

    _M_Ice.ACM = ACM
    del ACM

if 'Connection' not in _M_Ice.__dict__:
    _M_Ice.Connection = Ice.createTempClass()
    class Connection(object):
        """
        The user-level interface to a connection.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.Connection:
                raise RuntimeError('Ice.Connection is an abstract class')

        def close(self, force):
            """
            Close a connection, either gracefully or forcefully. If a
            connection is closed forcefully, it closes immediately, without
            sending the relevant close connection protocol messages to the
            peer and waiting for the peer to acknowledge these protocol
            messages.
            Arguments:
            force -- If true, close forcefully. Otherwise the connection is closed gracefully.
            """
            pass

        def createProxy(self, id):
            """
            Create a special proxy that always uses this connection. This
            can be used for callbacks from a server to a client if the
            server cannot directly establish a connection to the client,
            for example because of firewalls. In this case, the server
            would create a proxy using an already established connection
            from the client.
            Arguments:
            id -- The identity for which a proxy is to be created.
            Returns: A proxy that matches the given identity and uses this connection.
            """
            pass

        def setAdapter(self, adapter):
            """
            Explicitly set an object adapter that dispatches requests that
            are received over this connection. A client can invoke an
            operation on a server using a proxy, and then set an object
            adapter for the outgoing connection that is used by the proxy
            in order to receive callbacks. This is useful if the server
            cannot establish a connection back to the client, for example
            because of firewalls.
            Arguments:
            adapter -- The object adapter that should be used by this connection to dispatch requests. The object adapter must be activated. When the object adapter is deactivated, it is automatically removed from the connection.
            """
            pass

        def getAdapter(self):
            """
            Get the object adapter that dispatches requests for this
            connection.
            Returns: The object adapter that dispatches requests for the connection, or null if no adapter is set.
            """
            pass

        def getEndpoint(self):
            """
            Get the endpoint from which the connection was created.
            Returns: The endpoint from which the connection was created.
            """
            pass

        def flushBatchRequests(self):
            """
            Flush any pending batch requests for this connection.
            This means all batch requests invoked on fixed proxies
            associated with the connection.
            """
            pass

        def setCallback(self, callback):
            """
            Set callback on the connection. The callback is called by the
            connection when it's closed. The callback is called from the
            Ice thread pool associated with the connection.
            Arguments:
            callback -- The connection callback object.
            """
            pass

        def setACM(self, timeout, close, heartbeat):
            """
            Set the active connection management parameters.
            Arguments:
            timeout -- The timeout value in seconds.
            close -- The close condition
            heartbeat -- The hertbeat condition
            """
            pass

        def getACM(self):
            """
            Get the ACM parameters.
            Returns: The ACM parameters.
            """
            pass

        def type(self):
            """
            Return the connection type. This corresponds to the endpoint
            type, i.e., "tcp", "udp", etc.
            Returns: The type of the connection.
            """
            pass

        def timeout(self):
            """
            Get the timeout for the connection.
            Returns: The connection's timeout.
            """
            pass

        def toString(self):
            """
            Return a description of the connection as human readable text,
            suitable for logging or error messages.
            Returns: The description of the connection as human readable text.
            """
            pass

        def getInfo(self):
            """
            Returns the connection information.
            Returns: The connection information.
            """
            pass

        def setBufferSize(self, rcvSize, sndSize):
            """
            Set the connectiion buffer receive/send size.
            Arguments:
            rcvSize -- The connection receive buffer size.
            sndSize -- The connection send buffer size.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_Connection)

        __repr__ = __str__

    _M_Ice._t_Connection = IcePy.defineClass('::Ice::Connection', Connection, -1, (), True, False, None, (), ())
    Connection._ice_type = _M_Ice._t_Connection

    _M_Ice.Connection = Connection
    del Connection

if 'IPConnectionInfo' not in _M_Ice.__dict__:
    _M_Ice.IPConnectionInfo = Ice.createTempClass()
    class IPConnectionInfo(_M_Ice.ConnectionInfo):
        """
        Provides access to the connection details of an IP connection
        Members:
        localAddress -- The local address.
        localPort -- The local port.
        remoteAddress -- The remote address.
        remotePort -- The remote port.
        """
        def __init__(self, incoming=False, adapterName='', connectionId='', rcvSize=0, sndSize=0, localAddress="", localPort=-1, remoteAddress="", remotePort=-1):
            _M_Ice.ConnectionInfo.__init__(self, incoming, adapterName, connectionId, rcvSize, sndSize)
            self.localAddress = localAddress
            self.localPort = localPort
            self.remoteAddress = remoteAddress
            self.remotePort = remotePort

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_IPConnectionInfo)

        __repr__ = __str__

    _M_Ice._t_IPConnectionInfo = IcePy.defineClass('::Ice::IPConnectionInfo', IPConnectionInfo, -1, (), False, False, _M_Ice._t_ConnectionInfo, (), (
        ('localAddress', (), IcePy._t_string, False, 0),
        ('localPort', (), IcePy._t_int, False, 0),
        ('remoteAddress', (), IcePy._t_string, False, 0),
        ('remotePort', (), IcePy._t_int, False, 0)
    ))
    IPConnectionInfo._ice_type = _M_Ice._t_IPConnectionInfo

    _M_Ice.IPConnectionInfo = IPConnectionInfo
    del IPConnectionInfo

if 'TCPConnectionInfo' not in _M_Ice.__dict__:
    _M_Ice.TCPConnectionInfo = Ice.createTempClass()
    class TCPConnectionInfo(_M_Ice.IPConnectionInfo):
        """
        Provides access to the connection details of a TCP connection
        """
        def __init__(self, incoming=False, adapterName='', connectionId='', rcvSize=0, sndSize=0, localAddress="", localPort=-1, remoteAddress="", remotePort=-1):
            _M_Ice.IPConnectionInfo.__init__(self, incoming, adapterName, connectionId, rcvSize, sndSize, localAddress, localPort, remoteAddress, remotePort)

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_TCPConnectionInfo)

        __repr__ = __str__

    _M_Ice._t_TCPConnectionInfo = IcePy.defineClass('::Ice::TCPConnectionInfo', TCPConnectionInfo, -1, (), False, False, _M_Ice._t_IPConnectionInfo, (), ())
    TCPConnectionInfo._ice_type = _M_Ice._t_TCPConnectionInfo

    _M_Ice.TCPConnectionInfo = TCPConnectionInfo
    del TCPConnectionInfo

if 'UDPConnectionInfo' not in _M_Ice.__dict__:
    _M_Ice.UDPConnectionInfo = Ice.createTempClass()
    class UDPConnectionInfo(_M_Ice.IPConnectionInfo):
        """
        Provides access to the connection details of a UDP connection
        Members:
        mcastAddress -- The multicast address.
        mcastPort -- The multicast port.
        """
        def __init__(self, incoming=False, adapterName='', connectionId='', rcvSize=0, sndSize=0, localAddress="", localPort=-1, remoteAddress="", remotePort=-1, mcastAddress='', mcastPort=-1):
            _M_Ice.IPConnectionInfo.__init__(self, incoming, adapterName, connectionId, rcvSize, sndSize, localAddress, localPort, remoteAddress, remotePort)
            self.mcastAddress = mcastAddress
            self.mcastPort = mcastPort

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_UDPConnectionInfo)

        __repr__ = __str__

    _M_Ice._t_UDPConnectionInfo = IcePy.defineClass('::Ice::UDPConnectionInfo', UDPConnectionInfo, -1, (), False, False, _M_Ice._t_IPConnectionInfo, (), (
        ('mcastAddress', (), IcePy._t_string, False, 0),
        ('mcastPort', (), IcePy._t_int, False, 0)
    ))
    UDPConnectionInfo._ice_type = _M_Ice._t_UDPConnectionInfo

    _M_Ice.UDPConnectionInfo = UDPConnectionInfo
    del UDPConnectionInfo

if '_t_HeaderDict' not in _M_Ice.__dict__:
    _M_Ice._t_HeaderDict = IcePy.defineDictionary('::Ice::HeaderDict', (), IcePy._t_string, IcePy._t_string)

if 'WSConnectionInfo' not in _M_Ice.__dict__:
    _M_Ice.WSConnectionInfo = Ice.createTempClass()
    class WSConnectionInfo(_M_Ice.TCPConnectionInfo):
        """
        Provides access to the connection details of a WebSocket connection
        Members:
        headers -- The headers from the HTTP upgrade request.
        """
        def __init__(self, incoming=False, adapterName='', connectionId='', rcvSize=0, sndSize=0, localAddress="", localPort=-1, remoteAddress="", remotePort=-1, headers=None):
            _M_Ice.TCPConnectionInfo.__init__(self, incoming, adapterName, connectionId, rcvSize, sndSize, localAddress, localPort, remoteAddress, remotePort)
            self.headers = headers

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_WSConnectionInfo)

        __repr__ = __str__

    _M_Ice._t_WSConnectionInfo = IcePy.defineClass('::Ice::WSConnectionInfo', WSConnectionInfo, -1, (), False, False, _M_Ice._t_TCPConnectionInfo, (), (('headers', (), _M_Ice._t_HeaderDict, False, 0),))
    WSConnectionInfo._ice_type = _M_Ice._t_WSConnectionInfo

    _M_Ice.WSConnectionInfo = WSConnectionInfo
    del WSConnectionInfo

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `FileParser.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import IceGrid_Admin_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Start of module IceGrid
__name__ = 'IceGrid'

if 'ParseException' not in _M_IceGrid.__dict__:
    _M_IceGrid.ParseException = Ice.createTempClass()
    class ParseException(Ice.UserException):
        """
        This exception is raised if an error occurs during parsing.
        Members:
        reason -- The reason for the failure.
        """
        def __init__(self, reason=''):
            self.reason = reason

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'IceGrid::ParseException'

    _M_IceGrid._t_ParseException = IcePy.defineException('::IceGrid::ParseException', ParseException, (), False, None, (('reason', (), IcePy._t_string, False, 0),))
    ParseException._ice_type = _M_IceGrid._t_ParseException

    _M_IceGrid.ParseException = ParseException
    del ParseException

if 'FileParser' not in _M_IceGrid.__dict__:
    _M_IceGrid.FileParser = Ice.createTempClass()
    class FileParser(Ice.Object):
        """
        icegridadmin provides a FileParser
        object to transform XML files into ApplicationDescriptor
        objects.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.FileParser:
                raise RuntimeError('IceGrid.FileParser is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::FileParser')

        def ice_id(self, current=None):
            return '::IceGrid::FileParser'

        def ice_staticId():
            return '::IceGrid::FileParser'
        ice_staticId = staticmethod(ice_staticId)

        def parse(self, xmlFile, adminProxy, current=None):
            """
            Parse a file.
            Arguments:
            xmlFile -- Full pathname to the file.
            adminProxy -- An Admin proxy, used only to retrieve default templates when needed. May be null.
            current -- The Current object for the invocation.
            Returns: The application descriptor.
            Throws:
            ParseException -- Raised if an error occurred during parsing.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_FileParser)

        __repr__ = __str__

    _M_IceGrid.FileParserPrx = Ice.createTempClass()
    class FileParserPrx(Ice.ObjectPrx):

        """
        Parse a file.
        Arguments:
        xmlFile -- Full pathname to the file.
        adminProxy -- An Admin proxy, used only to retrieve default templates when needed. May be null.
        _ctx -- The request context for the invocation.
        Returns: The application descriptor.
        Throws:
        ParseException -- Raised if an error occurred during parsing.
        """
        def parse(self, xmlFile, adminProxy, _ctx=None):
            return _M_IceGrid.FileParser._op_parse.invoke(self, ((xmlFile, adminProxy), _ctx))

        """
        Parse a file.
        Arguments:
        xmlFile -- Full pathname to the file.
        adminProxy -- An Admin proxy, used only to retrieve default templates when needed. May be null.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_parse(self, xmlFile, adminProxy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.FileParser._op_parse.begin(self, ((xmlFile, adminProxy), _response, _ex, _sent, _ctx))

        """
        Parse a file.
        Arguments:
        xmlFile -- Full pathname to the file.
        adminProxy -- An Admin proxy, used only to retrieve default templates when needed. May be null.
        Returns: The application descriptor.
        Throws:
        ParseException -- Raised if an error occurred during parsing.
        """
        def end_parse(self, _r):
            return _M_IceGrid.FileParser._op_parse.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.FileParserPrx.ice_checkedCast(proxy, '::IceGrid::FileParser', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.FileParserPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::FileParser'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_FileParserPrx = IcePy.defineProxy('::IceGrid::FileParser', FileParserPrx)

    _M_IceGrid._t_FileParser = IcePy.defineClass('::IceGrid::FileParser', FileParser, -1, (), True, False, None, (), ())
    FileParser._ice_type = _M_IceGrid._t_FileParser

    FileParser._op_parse = IcePy.Operation('parse', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_IceGrid._t_AdminPrx, False, 0)), (), ((), _M_IceGrid._t_ApplicationDescriptor, False, 0), (_M_IceGrid._t_ParseException,))

    _M_IceGrid.FileParser = FileParser
    del FileParser

    _M_IceGrid.FileParserPrx = FileParserPrx
    del FileParserPrx

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::FileParser"] = "b847ccf3e3db7cbba649ec7cc464faf"
Ice.sliceChecksums["::IceGrid::ParseException"] = "dec9aacba8b3ba76afc5de1cc3489598"



# Generated by slice2py - DO NOT EDIT!
#

import Ice
Ice.updateModule("IceGrid")

# Modules:
import IceGrid_Admin_ice
import IceGrid_Descriptor_ice
import IceGrid_Exception_ice
import IceGrid_FileParser_ice
import IceGrid_Locator_ice
import IceGrid_Observer_ice
import IceGrid_Query_ice
import IceGrid_Registry_ice
import IceGrid_Session_ice
import IceGrid_UserAccountMapper_ice

# Submodules:



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `BuiltinSequences.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module Ice
_M_Ice = Ice.openModule('Ice')
__name__ = 'Ice'

if '_t_BoolSeq' not in _M_Ice.__dict__:
    _M_Ice._t_BoolSeq = IcePy.defineSequence('::Ice::BoolSeq', (), IcePy._t_bool)

if '_t_ByteSeq' not in _M_Ice.__dict__:
    _M_Ice._t_ByteSeq = IcePy.defineSequence('::Ice::ByteSeq', (), IcePy._t_byte)

if '_t_ShortSeq' not in _M_Ice.__dict__:
    _M_Ice._t_ShortSeq = IcePy.defineSequence('::Ice::ShortSeq', (), IcePy._t_short)

if '_t_IntSeq' not in _M_Ice.__dict__:
    _M_Ice._t_IntSeq = IcePy.defineSequence('::Ice::IntSeq', (), IcePy._t_int)

if '_t_LongSeq' not in _M_Ice.__dict__:
    _M_Ice._t_LongSeq = IcePy.defineSequence('::Ice::LongSeq', (), IcePy._t_long)

if '_t_FloatSeq' not in _M_Ice.__dict__:
    _M_Ice._t_FloatSeq = IcePy.defineSequence('::Ice::FloatSeq', (), IcePy._t_float)

if '_t_DoubleSeq' not in _M_Ice.__dict__:
    _M_Ice._t_DoubleSeq = IcePy.defineSequence('::Ice::DoubleSeq', (), IcePy._t_double)

if '_t_StringSeq' not in _M_Ice.__dict__:
    _M_Ice._t_StringSeq = IcePy.defineSequence('::Ice::StringSeq', (), IcePy._t_string)

if '_t_ObjectSeq' not in _M_Ice.__dict__:
    _M_Ice._t_ObjectSeq = IcePy.defineSequence('::Ice::ObjectSeq', (), IcePy._t_Object)

if '_t_ObjectProxySeq' not in _M_Ice.__dict__:
    _M_Ice._t_ObjectProxySeq = IcePy.defineSequence('::Ice::ObjectProxySeq', (), IcePy._t_ObjectPrx)

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `ImplicitContext.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_LocalException_ice
import Ice_Current_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Start of module Ice
__name__ = 'Ice'

if 'ImplicitContext' not in _M_Ice.__dict__:
    _M_Ice.ImplicitContext = Ice.createTempClass()
    class ImplicitContext(object):
        """
        An interface to associate implict contexts with communicators.
        When you make a remote invocation without an explicit context parameter,
        Ice uses the per-proxy context (if any) combined with the ImplicitContext
        associated with the communicator.
        Ice provides several implementations of ImplicitContext. The implementation
        used depends on the value of the Ice.ImplicitContext property.
        None (default)
        No implicit context at all.
        PerThread
        The implementation maintains a context per thread.
        Shared
        The implementation maintains a single context shared by all threads.
        ImplicitContext also provides a number of operations to create, update or retrieve
        an entry in the underlying context without first retrieving a copy of the entire
        context. These operations correspond to a subset of the java.util.Map methods,
        with java.lang.Object replaced by string and null replaced by the empty-string.
        """
        def __init__(self):
            if Ice.getType(self) == _M_Ice.ImplicitContext:
                raise RuntimeError('Ice.ImplicitContext is an abstract class')

        def getContext(self):
            """
            Get a copy of the underlying context.
            Returns: A copy of the underlying context.
            """
            pass

        def setContext(self, newContext):
            """
            Set the underlying context.
            Arguments:
            newContext -- The new context.
            """
            pass

        def containsKey(self, key):
            """
            Check if this key has an associated value in the underlying context. 
            Arguments:
            key -- The key.
            Returns: True if the key has an associated value, False otherwise.
            """
            pass

        def get(self, key):
            """
            Get the value associated with the given key in the underlying context.
            Returns an empty string if no value is associated with the key.
            containsKey allows you to distinguish between an empty-string value and 
            no value at all.
            Arguments:
            key -- The key.
            Returns: The value associated with the key.
            """
            pass

        def put(self, key, value):
            """
            Create or update a key/value entry in the underlying context.
            Arguments:
            key -- The key.
            value -- The value.
            Returns: The previous value associated with the key, if any.
            """
            pass

        def remove(self, key):
            """
            Remove the entry for the given key in the underlying context.
            Arguments:
            key -- The key.
            Returns: The value associated with the key, if any.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_Ice._t_ImplicitContext)

        __repr__ = __str__

    _M_Ice._t_ImplicitContext = IcePy.defineClass('::Ice::ImplicitContext', ImplicitContext, -1, (), True, False, None, (), ())
    ImplicitContext._ice_type = _M_Ice._t_ImplicitContext

    _M_Ice.ImplicitContext = ImplicitContext
    del ImplicitContext

# End of module Ice



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Metrics.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import Ice_Metrics_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module IceMX
_M_IceMX = Ice.openModule('IceMX')

# Start of module IceMX
__name__ = 'IceMX'

if 'SessionMetrics' not in _M_IceMX.__dict__:
    _M_IceMX.SessionMetrics = Ice.createTempClass()
    class SessionMetrics(_M_IceMX.Metrics):
        """
        Provides information on Glacier2 sessions.
        Members:
        forwardedClient -- Number of client requests forwared.
        forwardedServer -- Number of server requests forwared.
        routingTableSize -- The size of the routing table.
        queuedClient -- Number of client requests queued.
        queuedServer -- Number of server requests queued.
        overriddenClient -- Number of client requests overridden.
        overriddenServer -- Number of server requests overridden.
        """
        def __init__(self, id='', total=0, current=0, totalLifetime=0, failures=0, forwardedClient=0, forwardedServer=0, routingTableSize=0, queuedClient=0, queuedServer=0, overriddenClient=0, overriddenServer=0):
            _M_IceMX.Metrics.__init__(self, id, total, current, totalLifetime, failures)
            self.forwardedClient = forwardedClient
            self.forwardedServer = forwardedServer
            self.routingTableSize = routingTableSize
            self.queuedClient = queuedClient
            self.queuedServer = queuedServer
            self.overriddenClient = overriddenClient
            self.overriddenServer = overriddenServer

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceMX::Metrics', '::IceMX::SessionMetrics')

        def ice_id(self, current=None):
            return '::IceMX::SessionMetrics'

        def ice_staticId():
            return '::IceMX::SessionMetrics'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_IceMX._t_SessionMetrics)

        __repr__ = __str__

    _M_IceMX.SessionMetricsPrx = Ice.createTempClass()
    class SessionMetricsPrx(_M_IceMX.MetricsPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceMX.SessionMetricsPrx.ice_checkedCast(proxy, '::IceMX::SessionMetrics', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceMX.SessionMetricsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceMX::SessionMetrics'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceMX._t_SessionMetricsPrx = IcePy.defineProxy('::IceMX::SessionMetrics', SessionMetricsPrx)

    _M_IceMX._t_SessionMetrics = IcePy.defineClass('::IceMX::SessionMetrics', SessionMetrics, -1, (), False, False, _M_IceMX._t_Metrics, (), (
        ('forwardedClient', (), IcePy._t_int, False, 0),
        ('forwardedServer', (), IcePy._t_int, False, 0),
        ('routingTableSize', (), IcePy._t_int, False, 0),
        ('queuedClient', (), IcePy._t_int, False, 0),
        ('queuedServer', (), IcePy._t_int, False, 0),
        ('overriddenClient', (), IcePy._t_int, False, 0),
        ('overriddenServer', (), IcePy._t_int, False, 0)
    ))
    SessionMetrics._ice_type = _M_IceMX._t_SessionMetrics

    _M_IceMX.SessionMetrics = SessionMetrics
    del SessionMetrics

    _M_IceMX.SessionMetricsPrx = SessionMetricsPrx
    del SessionMetricsPrx

# End of module IceMX

Ice.sliceChecksums["::IceMX::SessionMetrics"] = "221020be2c80301fb4dbb779e21b190"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `UserAccountMapper.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy

# Start of module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')
__name__ = 'IceGrid'

if 'UserAccountNotFoundException' not in _M_IceGrid.__dict__:
    _M_IceGrid.UserAccountNotFoundException = Ice.createTempClass()
    class UserAccountNotFoundException(Ice.UserException):
        """
        This exception is raised if a user account for a given session
        identifier can't be found.
        """
        def __init__(self):
            pass

        def __str__(self):
            return IcePy.stringifyException(self)

        __repr__ = __str__

        _ice_name = 'IceGrid::UserAccountNotFoundException'

    _M_IceGrid._t_UserAccountNotFoundException = IcePy.defineException('::IceGrid::UserAccountNotFoundException', UserAccountNotFoundException, (), False, None, ())
    UserAccountNotFoundException._ice_type = _M_IceGrid._t_UserAccountNotFoundException

    _M_IceGrid.UserAccountNotFoundException = UserAccountNotFoundException
    del UserAccountNotFoundException

if 'UserAccountMapper' not in _M_IceGrid.__dict__:
    _M_IceGrid.UserAccountMapper = Ice.createTempClass()
    class UserAccountMapper(Ice.Object):
        """
        A user account mapper object is used by IceGrid nodes to map
        session identifiers to user accounts.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.UserAccountMapper:
                raise RuntimeError('IceGrid.UserAccountMapper is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::UserAccountMapper')

        def ice_id(self, current=None):
            return '::IceGrid::UserAccountMapper'

        def ice_staticId():
            return '::IceGrid::UserAccountMapper'
        ice_staticId = staticmethod(ice_staticId)

        def getUserAccount(self, user, current=None):
            """
            Get the name of the user account for the given user. This is
            used by IceGrid nodes to figure out the user account to use
            to run servers.
            Arguments:
            user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
            current -- The Current object for the invocation.
            Returns: The user account name.
            Throws:
            UserAccountNotFoundException -- Raised if no user account is found for the given user.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_UserAccountMapper)

        __repr__ = __str__

    _M_IceGrid.UserAccountMapperPrx = Ice.createTempClass()
    class UserAccountMapperPrx(Ice.ObjectPrx):

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        _ctx -- The request context for the invocation.
        Returns: The user account name.
        Throws:
        UserAccountNotFoundException -- Raised if no user account is found for the given user.
        """
        def getUserAccount(self, user, _ctx=None):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.invoke(self, ((user, ), _ctx))

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getUserAccount(self, user, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.begin(self, ((user, ), _response, _ex, _sent, _ctx))

        """
        Get the name of the user account for the given user. This is
        used by IceGrid nodes to figure out the user account to use
        to run servers.
        Arguments:
        user -- The value of the server descriptor's user attribute. If this attribute is not defined, and the server's activation mode is session, the default value of user is the session identifier.
        Returns: The user account name.
        Throws:
        UserAccountNotFoundException -- Raised if no user account is found for the given user.
        """
        def end_getUserAccount(self, _r):
            return _M_IceGrid.UserAccountMapper._op_getUserAccount.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.UserAccountMapperPrx.ice_checkedCast(proxy, '::IceGrid::UserAccountMapper', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.UserAccountMapperPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::UserAccountMapper'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_UserAccountMapperPrx = IcePy.defineProxy('::IceGrid::UserAccountMapper', UserAccountMapperPrx)

    _M_IceGrid._t_UserAccountMapper = IcePy.defineClass('::IceGrid::UserAccountMapper', UserAccountMapper, -1, (), True, False, None, (), ())
    UserAccountMapper._ice_type = _M_IceGrid._t_UserAccountMapper

    UserAccountMapper._op_getUserAccount = IcePy.Operation('getUserAccount', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), IcePy._t_string, False, 0), (_M_IceGrid._t_UserAccountNotFoundException,))

    _M_IceGrid.UserAccountMapper = UserAccountMapper
    del UserAccountMapper

    _M_IceGrid.UserAccountMapperPrx = UserAccountMapperPrx
    del UserAccountMapperPrx

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::UserAccountMapper"] = "779fd561878e199444e04cdebaf9ffd4"
Ice.sliceChecksums["::IceGrid::UserAccountNotFoundException"] = "fe2dc4d87f21b9b2cf6f1339d1666281"



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2018 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.5
#
# <auto-generated>
#
# Generated from file `Registry.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import IceGrid_Exception_ice
import IceGrid_Session_ice
import IceGrid_Admin_ice

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module IceGrid
_M_IceGrid = Ice.openModule('IceGrid')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Start of module IceGrid
__name__ = 'IceGrid'

if 'Registry' not in _M_IceGrid.__dict__:
    _M_IceGrid.Registry = Ice.createTempClass()
    class Registry(Ice.Object):
        """
        The IceGrid registry allows clients create sessions
        directly with the registry.
        """
        def __init__(self):
            if Ice.getType(self) == _M_IceGrid.Registry:
                raise RuntimeError('IceGrid.Registry is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::IceGrid::Registry')

        def ice_id(self, current=None):
            return '::IceGrid::Registry'

        def ice_staticId():
            return '::IceGrid::Registry'
        ice_staticId = staticmethod(ice_staticId)

        def createSession(self, userId, password, current=None):
            """
            Create a client session.
            Arguments:
            userId -- The user id.
            password -- The password for the given user id.
            current -- The Current object for the invocation.
            Returns: A proxy for the newly created session.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            pass

        def createAdminSession(self, userId, password, current=None):
            """
            Create an administrative session.
            Arguments:
            userId -- The user id.
            password -- The password for the given user id.
            current -- The Current object for the invocation.
            Returns: A proxy for the newly created session.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            pass

        def createSessionFromSecureConnection(self, current=None):
            """
            Create a client session from a secure connection.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A proxy for the newly created session.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            pass

        def createAdminSessionFromSecureConnection(self, current=None):
            """
            Create an administrative session from a secure connection.
            Arguments:
            current -- The Current object for the invocation.
            Returns: A proxy for the newly created session.
            Throws:
            PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
            """
            pass

        def getSessionTimeout(self, current=None):
            """
            Get the session timeout. If a client or administrative client
            doesn't call the session keepAlive method in the time interval
            defined by this timeout, IceGrid might reap the session.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The timeout (in seconds).
            """
            pass

        def getACMTimeout(self, current=None):
            """
            Get the value of the ACM timeout. Clients supporting ACM
            connection heartbeats can enable them instead of explicitly
            sending keep alives requests.
            NOTE: This method is only available since Ice 3.6.
            Arguments:
            current -- The Current object for the invocation.
            Returns: The timeout (in seconds).
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_IceGrid._t_Registry)

        __repr__ = __str__

    _M_IceGrid.RegistryPrx = Ice.createTempClass()
    class RegistryPrx(Ice.ObjectPrx):

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createSession(self, userId, password, _ctx=None):
            return _M_IceGrid.Registry._op_createSession.invoke(self, ((userId, password), _ctx))

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSession(self, userId, password, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_createSession.begin(self, ((userId, password), _response, _ex, _sent, _ctx))

        """
        Create a client session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createSession(self, _r):
            return _M_IceGrid.Registry._op_createSession.end(self, _r)

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createAdminSession(self, userId, password, _ctx=None):
            return _M_IceGrid.Registry._op_createAdminSession.invoke(self, ((userId, password), _ctx))

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createAdminSession(self, userId, password, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_createAdminSession.begin(self, ((userId, password), _response, _ex, _sent, _ctx))

        """
        Create an administrative session.
        Arguments:
        userId -- The user id.
        password -- The password for the given user id.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createAdminSession(self, _r):
            return _M_IceGrid.Registry._op_createAdminSession.end(self, _r)

        """
        Create a client session from a secure connection.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createSessionFromSecureConnection(self, _ctx=None):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.invoke(self, ((), _ctx))

        """
        Create a client session from a secure connection.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createSessionFromSecureConnection(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Create a client session from a secure connection.
        Arguments:
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createSessionFromSecureConnection(self, _r):
            return _M_IceGrid.Registry._op_createSessionFromSecureConnection.end(self, _r)

        """
        Create an administrative session from a secure connection.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def createAdminSessionFromSecureConnection(self, _ctx=None):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.invoke(self, ((), _ctx))

        """
        Create an administrative session from a secure connection.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_createAdminSessionFromSecureConnection(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Create an administrative session from a secure connection.
        Arguments:
        Returns: A proxy for the newly created session.
        Throws:
        PermissionDeniedException -- Raised if the password for the given user id is not correct, or if the user is not allowed access.
        """
        def end_createAdminSessionFromSecureConnection(self, _r):
            return _M_IceGrid.Registry._op_createAdminSessionFromSecureConnection.end(self, _r)

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getSessionTimeout(self, _ctx=None):
            return _M_IceGrid.Registry._op_getSessionTimeout.invoke(self, ((), _ctx))

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getSessionTimeout(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_getSessionTimeout.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the session timeout. If a client or administrative client
        doesn't call the session keepAlive method in the time interval
        defined by this timeout, IceGrid might reap the session.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getSessionTimeout(self, _r):
            return _M_IceGrid.Registry._op_getSessionTimeout.end(self, _r)

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        _ctx -- The request context for the invocation.
        Returns: The timeout (in seconds).
        """
        def getACMTimeout(self, _ctx=None):
            return _M_IceGrid.Registry._op_getACMTimeout.invoke(self, ((), _ctx))

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getACMTimeout(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_IceGrid.Registry._op_getACMTimeout.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Get the value of the ACM timeout. Clients supporting ACM
        connection heartbeats can enable them instead of explicitly
        sending keep alives requests.
        NOTE: This method is only available since Ice 3.6.
        Arguments:
        Returns: The timeout (in seconds).
        """
        def end_getACMTimeout(self, _r):
            return _M_IceGrid.Registry._op_getACMTimeout.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_IceGrid.RegistryPrx.ice_checkedCast(proxy, '::IceGrid::Registry', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_IceGrid.RegistryPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::IceGrid::Registry'
        ice_staticId = staticmethod(ice_staticId)

    _M_IceGrid._t_RegistryPrx = IcePy.defineProxy('::IceGrid::Registry', RegistryPrx)

    _M_IceGrid._t_Registry = IcePy.defineClass('::IceGrid::Registry', Registry, -1, (), True, False, None, (), ())
    Registry._ice_type = _M_IceGrid._t_Registry

    Registry._op_createSession = IcePy.Operation('createSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_IceGrid._t_SessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createAdminSession = IcePy.Operation('createAdminSession', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_string, False, 0), ((), IcePy._t_string, False, 0)), (), ((), _M_IceGrid._t_AdminSessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createSessionFromSecureConnection = IcePy.Operation('createSessionFromSecureConnection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_IceGrid._t_SessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_createAdminSessionFromSecureConnection = IcePy.Operation('createAdminSessionFromSecureConnection', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_IceGrid._t_AdminSessionPrx, False, 0), (_M_IceGrid._t_PermissionDeniedException,))
    Registry._op_getSessionTimeout = IcePy.Operation('getSessionTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Registry._op_getACMTimeout = IcePy.Operation('getACMTimeout', Ice.OperationMode.Idempotent, Ice.OperationMode.Nonmutating, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())

    _M_IceGrid.Registry = Registry
    del Registry

    _M_IceGrid.RegistryPrx = RegistryPrx
    del RegistryPrx

# End of module IceGrid

Ice.sliceChecksums["::IceGrid::Registry"] = "8298cc0aba1a722d75eb79034fbb076"
